---
title: R Markdown Vignettes with litedown
author: Yihui Xie
date: "`{r} Sys.Date()`"
output:
  html:
    meta:
      css: ["@default"]
---

<!--
%\VignetteEngine{litedown::vignette}
%\VignetteIndexEntry{R Markdown Vignettes with litedown}
-->

Before R 3.0.0, only Sweave/PDF vignettes were supported in R. Markdown is gaining popularity over the years due to its simplicity, and R 3.0.0 starts to support package vignettes written in R Markdown.

> Please note this example is for [litedown](https://cran.r-project.org/package=litedown). If you use [R Markdown v2](https://rmarkdown.rstudio.com), you should use the vignette engine `knitr::rmarkdown` instead of `litedown::vignette`.

## Package vignettes

To enable Markdown vignettes in an R package, you need to

- add `*.Rmd` files under the `vignettes` directory
- add `VignetteBuilder: litedown` to the `DESCRIPTION` file
- specify the vignette engine `\VignetteEngine{litedown::vignette}` in the `Rmd` files (inside HTML comments)

## View vignettes

And R will load the **litedown** package to build these vignettes to HTML files, and you can see them when you open the HTML help:

```{r eval=FALSE}
help(package = 'YourPackage', help_type = 'html')
# or see a standalone list of vignettes
browseVignettes('YourPackage')
```

## Examples

Below are some code chunks as examples.

```{r hello, results='asis'}
if (TRUE) cat('_hello_ **markdown**!', '\n')
```

Normally you do not need any chunk options.

```{r test, collapse=TRUE}
1+1
10:1
rnorm(5)^2
strsplit('hello, markdown vignettes', '')
```

Feel free to draw beautiful plots and write math $P(X>x)=\alpha/2$.

```{r}
n=300; set.seed(123)
par(mar=c(4,4,.1,.1))
plot(rnorm(n), rnorm(n), pch=21, cex=5*runif(n), col='white', bg='gray')
```
