`r if (exists('.knitr.title')) I(paste('#', .knitr.title, sep = ''))`

`r if (exists('.knitr.author')) I(.knitr.author)`

This report was automatically generated with the R package **knitr**
(version `r packageVersion('knitr')`).

```{r %sCHUNK_LABEL_HERE}
```

The R session information (including the OS info, R version and all
packages used):

```{r session-info, cache=FALSE}
sessionInfo()
Sys.time()
```
```{r clean-up, include=FALSE}
if (exists('.knitr.title')) rm(.knitr.author)
if (exists('.knitr.author')) rm(.knitr.author)
```
