#LyX 2.0 created this file. For more info see http://www.lyx.org/
\lyxformat 413
\begin_document
\begin_header
\textclass article
\use_default_options true
\begin_modules
knitr
\end_modules
\maintain_unincluded_children false
\language english
\language_package none
\inputencoding default
\fontencoding global
\font_roman palatino
\font_sans default
\font_typewriter default
\font_default_family default
\use_non_tex_fonts false
\font_sc true
\font_osf false
\font_sf_scale 100
\font_tt_scale 100

\graphics default
\default_output_format default
\output_sync 0
\bibtex_command default
\index_command default
\paperfontsize default
\spacing single
\use_hyperref true
\pdf_bookmarks true
\pdf_bookmarksnumbered true
\pdf_bookmarksopen true
\pdf_bookmarksopenlevel 2
\pdf_breaklinks false
\pdf_pdfborder false
\pdf_colorlinks false
\pdf_backref false
\pdf_pdfusetitle true
\pdf_quoted_options "pdfstartview={XYZ null null 1}"
\papersize default
\use_geometry true
\use_amsmath 1
\use_esint 1
\use_mhchem 1
\use_mathdots 1
\cite_engine basic
\use_bibtopic false
\use_indices false
\paperorientation portrait
\suppress_date false
\use_refstyle 1
\index Index
\shortcut idx
\color #008000
\end_index
\leftmargin 2.5cm
\topmargin 2.5cm
\rightmargin 2.5cm
\bottommargin 2.5cm
\secnumdepth 2
\tocdepth 2
\paragraph_separation indent
\paragraph_indentation default
\quotes_language english
\papercolumns 1
\papersides 1
\paperpagestyle default
\tracking_changes false
\output_changes false
\html_math_output 0
\html_css_as_file 0
\html_be_strict false
\end_header

\begin_body

\begin_layout Standard
\begin_inset ERT
status open

\begin_layout Plain Layout

<<setup, include=FALSE, cache=FALSE>>=
\end_layout

\begin_layout Plain Layout

library(knitr)
\end_layout

\begin_layout Plain Layout

# set global chunk options
\end_layout

\begin_layout Plain Layout

opts_chunk$set(fig.path='figure/minimal-', fig.align='center', fig.show='hold')
\end_layout

\begin_layout Plain Layout

options(formatR.arrow=TRUE,width=90)
\end_layout

\begin_layout Plain Layout

@
\end_layout

\end_inset


\end_layout

\begin_layout Title
A Minimal Demo of knitr
\end_layout

\begin_layout Author
Yihui Xie
\end_layout

\begin_layout Standard
You can test if 
\series bold
knitr
\series default
 works with this minimal demo.
 OK, let's get started with some boring random numbers:
\end_layout

\begin_layout Standard
\begin_inset ERT
status open

\begin_layout Plain Layout

<<boring-random>>=
\end_layout

\begin_layout Plain Layout

set.seed(1121)
\end_layout

\begin_layout Plain Layout

(x=rnorm(20))
\end_layout

\begin_layout Plain Layout

mean(x);var(x)
\end_layout

\begin_layout Plain Layout

@
\end_layout

\end_inset


\end_layout

\begin_layout Standard
The first element of 
\family typewriter
x
\family default
 is 
\begin_inset ERT
status collapsed

\begin_layout Plain Layout


\backslash
Sexpr{x[1]}
\end_layout

\end_inset

.
 Boring boxplots and histograms recorded by the PDF device:
\end_layout

\begin_layout Standard
\begin_inset ERT
status open

\begin_layout Plain Layout

<<boring-plots, fig.width=4, fig.height=4, out.width='.4
\backslash

\backslash
linewidth'>>=
\end_layout

\begin_layout Plain Layout

## two plots side by side (option fig.show='hold')
\end_layout

\begin_layout Plain Layout

par(mar=c(4,4,.1,.1),cex.lab=.95,cex.axis=.9,mgp=c(2,.7,0),tcl=-.3,las=1)
\end_layout

\begin_layout Plain Layout

boxplot(x)
\end_layout

\begin_layout Plain Layout

hist(x,main='')
\end_layout

\begin_layout Plain Layout

@
\end_layout

\end_inset


\end_layout

\begin_layout Standard
Do the above chunks work? You should be able to compile the TeX document
 and get a PDF file like this one: 
\begin_inset Flex URL
status collapsed

\begin_layout Plain Layout

https://github.com/yihui/knitr/releases/download/doc/knitr-minimal.pdf
\end_layout

\end_inset

.
 The Rnw source of this document is at 
\begin_inset Flex URL
status collapsed

\begin_layout Plain Layout

https://github.com/yihui/knitr/blob/master/inst/examples/knitr-minimal.Rnw
\end_layout

\end_inset

.
\end_layout

\end_body
\end_document
