#LyX 2.0 created this file. For more info see http://www.lyx.org/
\lyxformat 413
\begin_document
\begin_header
\textclass article
\begin_preamble
\renewcommand{\textfraction}{0.05}
\renewcommand{\topfraction}{0.8}
\renewcommand{\bottomfraction}{0.8}
\renewcommand{\floatpagefraction}{0.75}
\end_preamble
\use_default_options true
\begin_modules
knitr
\end_modules
\maintain_unincluded_children false
\language english
\language_package none
\inputencoding default
\fontencoding global
\font_roman palatino
\font_sans default
\font_typewriter default
\font_default_family default
\use_non_tex_fonts false
\font_sc true
\font_osf false
\font_sf_scale 100
\font_tt_scale 100

\graphics default
\default_output_format default
\output_sync 0
\bibtex_command default
\index_command default
\paperfontsize default
\spacing single
\use_hyperref true
\pdf_bookmarks true
\pdf_bookmarksnumbered true
\pdf_bookmarksopen true
\pdf_bookmarksopenlevel 2
\pdf_breaklinks false
\pdf_pdfborder false
\pdf_colorlinks false
\pdf_backref false
\pdf_pdfusetitle true
\pdf_quoted_options "pdfstartview={XYZ null null 1}"
\papersize default
\use_geometry true
\use_amsmath 1
\use_esint 1
\use_mhchem 1
\use_mathdots 1
\cite_engine basic
\use_bibtopic false
\use_indices false
\paperorientation portrait
\suppress_date false
\use_refstyle 1
\index Index
\shortcut idx
\color #008000
\end_index
\leftmargin 3cm
\topmargin 3cm
\rightmargin 3cm
\bottommargin 3cm
\secnumdepth 2
\tocdepth 2
\paragraph_separation skip
\defskip bigskip
\quotes_language english
\papercolumns 2
\papersides 1
\paperpagestyle default
\tracking_changes false
\output_changes false
\html_math_output 0
\html_css_as_file 0
\html_be_strict false
\end_header

\begin_body

\begin_layout Standard
\begin_inset ERT
status open

\begin_layout Plain Layout

<<setup, include=FALSE, cache=FALSE>>=
\end_layout

\begin_layout Plain Layout

opts_chunk$set(fig.path='figure/twocolumn-', fig.align='center', fig.show='hold')
\end_layout

\begin_layout Plain Layout

render_listings()
\end_layout

\begin_layout Plain Layout

@
\end_layout

\end_inset


\end_layout

\begin_layout Title
Using knitr in A Two-column Document
\end_layout

\begin_layout Author
Yihui Xie
\end_layout

\begin_layout Standard
We can use the 
\family typewriter
figure*
\family default
 environment in LaTeX so that figures can span over two columns.
 Because the output hooks use the 
\series bold
framed
\series default
 package which does not work well with the 
\family typewriter
figure*
\family default
 environment, we can either modify the output hooks or use other packages
 like 
\series bold
listings
\series default
.
 For example,
\end_layout

\begin_layout Standard
\begin_inset ERT
status open

\begin_layout Plain Layout

<<chunk-hook, echo=2>>=
\end_layout

\begin_layout Plain Layout

<<setup>>
\end_layout

\begin_layout Plain Layout

@
\end_layout

\end_inset


\end_layout

\begin_layout Standard
\begin_inset Float figure
wide true
sideways false
status open

\begin_layout Plain Layout
\begin_inset ERT
status open

\begin_layout Plain Layout

<<boring-plots, fig.width=5, fig.height=5, out.width='.45
\backslash

\backslash
linewidth'>>=
\end_layout

\begin_layout Plain Layout

x=rnorm(100)
\end_layout

\begin_layout Plain Layout

par(mar=c(4,4,.1,.1))
\end_layout

\begin_layout Plain Layout

boxplot(x)
\end_layout

\begin_layout Plain Layout

hist(x,main='')
\end_layout

\begin_layout Plain Layout

@
\end_layout

\end_inset


\end_layout

\begin_layout Plain Layout
\begin_inset Caption

\begin_layout Plain Layout
Two plots spanning over two columns.
\end_layout

\end_inset


\end_layout

\end_inset


\end_layout

\begin_layout Standard
The output PDF file will be like: 
\begin_inset Flex URL
status collapsed

\begin_layout Plain Layout

https://bitbucket.org/stat/knitr/downloads/knitr-twocolumn.pdf
\end_layout

\end_inset

.
 The Rnw source of this document is at 
\begin_inset Flex URL
status collapsed

\begin_layout Plain Layout

https://github.com/yihui/knitr/blob/master/inst/examples/knitr-twocolumn.Rnw
\end_layout

\end_inset

.
\end_layout

\end_body
\end_document
