#LyX 2.0 created this file. For more info see http://www.lyx.org/
\lyxformat 413
\begin_document
\begin_header
\textclass beamer
\begin_preamble
\usetheme{PaloAlto}
\end_preamble
\use_default_options true
\begin_modules
knitr
beamer-fragile
\end_modules
\maintain_unincluded_children false
\language english
\language_package none
\inputencoding default
\fontencoding global
\font_roman default
\font_sans default
\font_typewriter default
\font_default_family default
\use_non_tex_fonts false
\font_sc false
\font_osf false
\font_sf_scale 100
\font_tt_scale 100

\graphics default
\default_output_format default
\output_sync 0
\bibtex_command default
\index_command default
\paperfontsize 10
\spacing single
\use_hyperref true
\pdf_bookmarks true
\pdf_bookmarksnumbered false
\pdf_bookmarksopen false
\pdf_bookmarksopenlevel 1
\pdf_breaklinks false
\pdf_pdfborder true
\pdf_colorlinks false
\pdf_backref false
\pdf_pdfusetitle true
\papersize default
\use_geometry true
\use_amsmath 1
\use_esint 1
\use_mhchem 1
\use_mathdots 1
\cite_engine basic
\use_bibtopic false
\use_indices false
\paperorientation portrait
\suppress_date false
\use_refstyle 1
\index Index
\shortcut idx
\color #008000
\end_index
\secnumdepth 3
\tocdepth 3
\paragraph_separation indent
\paragraph_indentation default
\quotes_language english
\papercolumns 1
\papersides 1
\paperpagestyle default
\tracking_changes false
\output_changes false
\html_math_output 0
\html_css_as_file 0
\html_be_strict false
\end_header

\begin_body

\begin_layout Standard
\begin_inset ERT
status open

\begin_layout Plain Layout

<<setup, include=FALSE>>=
\end_layout

\begin_layout Plain Layout

opts_chunk$set(fig.path='figure/beamer-',fig.align='center',fig.show='hold',size='f
ootnotesize')
\end_layout

\begin_layout Plain Layout

@
\end_layout

\end_inset


\end_layout

\begin_layout Title
\begin_inset Argument
status collapsed

\begin_layout Plain Layout
knitr, Beamer, and FragileFrame
\end_layout

\end_inset

A Minimal Demo of knitr with Beamer and Fragile Frames
\end_layout

\begin_layout Author
Yihui Xie
\begin_inset Foot
status open

\begin_layout Plain Layout
I thank Richard E.
 Goldberg for providing this demo.
\end_layout

\end_inset


\end_layout

\begin_layout EndFrame

\end_layout

\begin_layout BeginFrame
Background
\end_layout

\begin_layout Itemize
The 
\series bold
knitr
\emph on
 
\series default
\emph default
package allows you to embed R code and figures in LaTeX documents
\end_layout

\begin_deeper
\begin_layout Itemize
It has functionality similar to Sweave but looks nicer and gives you more
 control
\end_layout

\end_deeper
\begin_layout Itemize
If you already have Sweave working in LyX, getting 
\series bold
knitr
\series default
 to work is trivial
\end_layout

\begin_deeper
\begin_layout Enumerate
Install the 
\series bold
knitr
\series default
 package in 
\emph on
R
\end_layout

\begin_layout Enumerate
Read 
\begin_inset Flex URL
status collapsed

\begin_layout Plain Layout

http://yihui.name/knitr/demo/lyx/
\end_layout

\end_inset


\end_layout

\end_deeper
\begin_layout Itemize
If you use Sweave or 
\series bold
knitr
\series default
 with Beamer in LyX, you probably use the 
\emph on
Beamer Fragile
\emph default
 module
\begin_inset Foot
status open

\begin_layout Plain Layout
\begin_inset Flex URL
status collapsed

\begin_layout Plain Layout

http://www.lyx.org/trac/ticket/7273
\end_layout

\end_inset


\end_layout

\end_inset

 too.
 Let's see if 
\series bold
knitr
\series default
 works with Beamer in this small demo.
 
\end_layout

\begin_layout Section
First Test
\end_layout

\begin_layout Standard
\begin_inset Flex FragileFrame
status open

\begin_layout FrameTitle
First Test
\end_layout

\begin_layout Plain Layout
OK, let's get started with just some text:
\end_layout

\begin_layout Plain Layout
\begin_inset ERT
status open

\begin_layout Plain Layout

<<echo=FALSE,results='hide'>>=
\end_layout

\begin_layout Plain Layout

# some setup
\end_layout

\begin_layout Plain Layout

options(width=60)  # make the printing fit on the page
\end_layout

\begin_layout Plain Layout

set.seed(1121)   # make the results repeatable
\end_layout

\begin_layout Plain Layout

@
\end_layout

\begin_layout Plain Layout

\end_layout

\begin_layout Plain Layout

<<>>= 
\end_layout

\begin_layout Plain Layout

# create some random numbers
\end_layout

\begin_layout Plain Layout

(x=rnorm(20))  
\end_layout

\begin_layout Plain Layout

mean(x);var(x)  
\end_layout

\begin_layout Plain Layout

@
\end_layout

\end_inset


\end_layout

\begin_layout Plain Layout
BTW, the first element of 
\family typewriter
x
\family default
 is 
\begin_inset ERT
status open

\begin_layout Plain Layout


\backslash
Sexpr{x[1]}
\end_layout

\end_inset

.
 (Did you notice the use of
\family typewriter
 
\backslash
Sexpr{}
\family default
.)
\end_layout

\end_inset


\end_layout

\begin_layout Section
Second Test
\end_layout

\begin_layout Standard
\begin_inset Flex FragileFrame
status open

\begin_layout FrameTitle
Second Test
\end_layout

\begin_layout Plain Layout
Text is nice but let's see what happens if we make a couple of plots in
 our chunk:
\end_layout

\begin_layout Plain Layout
\begin_inset ERT
status open

\begin_layout Plain Layout

<<boring-plots,fig.width=4,fig.height=4,out.width='.45
\backslash

\backslash
linewidth'>>=
\end_layout

\begin_layout Plain Layout

par(las=1,mar=c(4,4,.1,.1))  # tick labels direction
\end_layout

\begin_layout Plain Layout

boxplot(x) 
\end_layout

\begin_layout Plain Layout

hist(x,main='',col="blue",probability=TRUE) 
\end_layout

\begin_layout Plain Layout

lines(density(x),col="red")
\end_layout

\begin_layout Plain Layout

@
\end_layout

\end_inset


\end_layout

\end_inset


\end_layout

\begin_layout Section
The Big Question
\end_layout

\begin_layout BeginFrame
The Big Question
\end_layout

\begin_layout Standard
Do the above chunks work? You should be able to compile the LyX document
 and get a nice-looking PDF slide presentation.
 If not, time to double-check everything...
\end_layout

\begin_layout EndFrame

\end_layout

\end_body
\end_document
