<!--
%\VignetteEngine{knitr::docco_classic}
%\VignetteIndexEntry{R Markdown with the Docco Classic Style}
-->

# R Markdown with the Docco Classic Style

```{r setup, echo=FALSE, results='asis'}
x = readLines('docco-linear.Rmd')[-(1:7)]
x = gsub('linear', 'classic', x)
i = grep('^knit2html[(][.]{3}', x)
x[i - 1] = '```{r}'
x[i] = 'head(knitr::rocco, 5)'
library(knitr)
cat(knit_child(text = x, quiet = TRUE), sep = '\n')
```

You probably have noticed that you can adjust the widths of the two columns
using your cursor. What is more, press `T` on your keyboard, and see what
happens.
