\documentclass{article}
\usepackage{mathpazo}
\begin{document}
This main document has several children.

<<test-main>>=
1+1
@
<<test-child, child=c('knitr-child-a.Rnw', 'knitr-child-b.Rnw')>>=
@

<<test-child-dir, child='sub/knitr-child-c.Rnw'>>=
@

\end{document}
